@@ -15,7 +15,7 @@ use YAML::Syck;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.1.7');
+our $VERSION = version->new('0.1.8');
 our $NAME    = 'recent';
 our $OPTIONS = [
     'max|m=i',
@@ -36,7 +36,7 @@ sub run {
     my $max = $self->defaults->{max} || 10;
     $max = scalar @sessions if $max - 1 > @sessions;
 
-    for my $session (@sessions[0 .. $max - 1]) {
+    for my $session ((reverse @sessions)[0 .. $max - 1]) {
         print localtime($sessions->{sessions}{$session}{time}) . "\t$session\n";
     }
 
@@ -57,7 +57,7 @@ App::VTide::Command::Recent - List recent App::VTide sessions
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Recent version 0.1.7
+This documentation refers to App::VTide::Command::Recent version 0.1.8
 
 =head1 SYNOPSIS
 
